From 192adebda1993784520098bee2d4f456c0b0e2ab Mon Sep 17 00:00:00 2001
From: Miroslav Rezanina <mrezanin@redhat.com>
Date: Wed, 6 Nov 2013 15:43:26 +0100
Subject: [PATCH 119/212] Build ceph/rbd only for rhev

RH-Author: Miroslav Rezanina <mrezanin@redhat.com>
Message-id: <58854c39ceb485b1ea685c02398db4462493dd35.1383752552.git.mrezanin@redhat.com>
Patchwork-id: 55544
O-Subject: [RHEL7 qemu-kvm PATCH] Build ceph/rbd only for rhev
Bugzilla: 987583
RH-Acked-by: Kevin Wolf <kwolf@redhat.com>
RH-Acked-by: Paolo Bonzini <pbonzini@redhat.com>
RH-Acked-by: Stefan Hajnoczi <stefanha@redhat.com>

From: Miroslav Rezanina <mrezanin@redhat.com>

Bugzilla: https://bugzilla.redhat.com/show_bug.cgi?id=987583
Brewbuild: http://brewweb.devel.redhat.com/brew/taskinfo?taskID=6536646 (RHEL)
Brewbuild: http://brewweb.devel.redhat.com/brew/taskinfo?taskID=6536615 (RHEV)

We support ceph/rbd only for rhev qemu-kvm so it has to be disabled for rhel
qemu-kvm. This patch forwardport RHEL-6 way of disabling rbd but use new
way of handling introduced by Jeff Cody.

This patch is based on Jeff's "RHEL Storage Differentiation" series and should be
applied with it. Both brew build include all 4 differentiation patches.

Signed-off-by: Miroslav Rezanina <mrezanin@redhat.com>
---
 block/Makefile.objs           |  2 +-
 configure                     | 11 +++++++++++
 redhat/qemu-kvm.spec.template |  6 ++++++
 3 files changed, 18 insertions(+), 1 deletion(-)

Signed-off-by: Miroslav Rezanina <mrezanin@redhat.com>
---
 block/Makefile.objs           |    2 +-
 configure                     |   12 +++++++++++-
 redhat/qemu-kvm.spec.template |    6 ++++++
 3 files changed, 18 insertions(+), 2 deletions(-)

diff --git a/block/Makefile.objs b/block/Makefile.objs
index e078f17..557bca3 100644
--- a/block/Makefile.objs
+++ b/block/Makefile.objs
@@ -15,7 +15,7 @@ block-obj-y += nbd.o nbd-client.o sheepdog.o
 block-obj-$(CONFIG_LIBISCSI) += iscsi.o
 block-obj-$(CONFIG_LIBNFS) += nfs.o
 block-obj-$(CONFIG_CURL) += curl.o
-block-obj-y += rbd.o
+block-obj-$(CONFIG_CEPH_SUPPORT) += rbd.o
 block-obj-$(CONFIG_GLUSTERFS) += gluster.o
 block-obj-$(CONFIG_LIBSSH2) += ssh.o
 endif
diff --git a/configure b/configure
index 3309e3a..c104d53 100755
--- a/configure
+++ b/configure
@@ -335,9 +335,9 @@ vhdx=""
 quorum=""
 live_block_ops="yes"
 live_block_migration="no"
+ceph_support="yes"
 numa=""
 
-
 # parse CC options first
 for opt do
   optarg=`expr "x$opt" : 'x[^=]*=\(.*\)'`
@@ -1131,6 +1131,10 @@ for opt do
   ;;
   --enable-live-block-migration) live_block_migration="yes"
   ;;
+  --disable-ceph-support) ceph_support=="no"
+  ;;
+  --enable-ceph-support) ceph_support=="yes"
+  ;;
   *)
       echo "ERROR: unknown option $opt"
       echo "Try '$0 --help' for more information"
@@ -1401,6 +1405,8 @@ Advanced options (experts only):
   --enable-live-block-ops  enable live block operations support
   --disable-live-block-migration disable live block migration
   --enable-live-block-migration  enable live block migration
+  --disable-ceph-support   disable support for rbd block driver support
+  --enable-ceph-support    enable support for rbd block driver support
   --disable-numa           disable libnuma support
   --enable-numa            enable libnuma support
 
@@ -4693,6 +4699,10 @@ if test "$live_block_migration" = "yes" ; then
   echo "CONFIG_LIVE_BLOCK_MIGRATION=y" >> $config_host_mak
 fi
 
+if test "ceph_support" = "yes"; then
+  echo "CONFIG_CEPH_SUPPORT=y" >> $config_host_mak
+fi
+
 # USB host support
 if test "$libusb" = "yes"; then
   echo "HOST_USB=libusb legacy" >> $config_host_mak
-- 
1.7.1

